kvarn_async::prelude::compact_str::core::marker

Trait StructuralPartialEq

source
pub trait StructuralPartialEq { }
๐Ÿ”ฌThis is a nightly-only experimental API. (structural_match)
Required trait for constants used in pattern matches.

Any type that derives PartialEq automatically implements this trait, regardless of whether its type-parameters implement PartialEq.

If a const item contains some type that does not implement this trait, then that type either (1.) does not implement PartialEq (which means the constant will not provide that comparison method, which code generation assumes is available), or (2.) it implements its own version of PartialEq (which we assume does not conform to a structural-equality comparison).

In either of the two scenarios above, we reject usage of such a constant in a pattern match.

See also the structural match RFC, and issue 63438 which motivated migrating from an attribute-based design to this trait.

Implementors

1.7.0 ยท source

impl StructuralPartialEq for IpAddr

1.0.0 ยท source

impl StructuralPartialEq for SocketAddr

1.28.0 ยท source

impl StructuralPartialEq for kvarn_async::prelude::fmt::Alignment

1.0.0 ยท source

impl StructuralPartialEq for ErrorKind

1.0.0 ยท source

impl StructuralPartialEq for SeekFrom

source

impl StructuralPartialEq for Ipv6MulticastScope

1.0.0 ยท source

impl StructuralPartialEq for Shutdown

source

impl StructuralPartialEq for CacheControlError

source

impl StructuralPartialEq for RequestParseStage

source

impl StructuralPartialEq for SanitizeError



impl StructuralPartialEq for ToCompactStringError

source

impl StructuralPartialEq for AsciiChar

1.0.0 ยท source

impl StructuralPartialEq for kvarn_async::prelude::compact_str::core::cmp::Ordering

1.0.0 ยท source

impl StructuralPartialEq for FpCategory

1.55.0 ยท source

impl StructuralPartialEq for IntErrorKind

source

impl StructuralPartialEq for SearchStep

1.0.0 ยท source

impl StructuralPartialEq for kvarn_async::prelude::compact_str::core::sync::atomic::Ordering

source

impl StructuralPartialEq for TryReserveErrorKind

1.65.0 ยท source

impl StructuralPartialEq for BacktraceStatus

1.0.0 ยท source

impl StructuralPartialEq for VarError

source

impl StructuralPartialEq for BacktraceStyle

1.12.0 ยท source

impl StructuralPartialEq for RecvTimeoutError

1.0.0 ยท source

impl StructuralPartialEq for std::sync::mpsc::TryRecvError

source

impl StructuralPartialEq for _Unwind_Action

source

impl StructuralPartialEq for _Unwind_Reason_Code

source

impl StructuralPartialEq for Level

source

impl StructuralPartialEq for LevelFilter

source

impl StructuralPartialEq for bool

source

impl StructuralPartialEq for char

source

impl StructuralPartialEq for i8

source

impl StructuralPartialEq for i16

source

impl StructuralPartialEq for i32

source

impl StructuralPartialEq for i64

source

impl StructuralPartialEq for i128

source

impl StructuralPartialEq for isize

source

impl StructuralPartialEq for str

source

impl StructuralPartialEq for u8

source

impl StructuralPartialEq for u16

source

impl StructuralPartialEq for u32

source

impl StructuralPartialEq for u64

source

impl StructuralPartialEq for u128

source

impl StructuralPartialEq for ()

source

impl StructuralPartialEq for usize

1.0.0 ยท source

impl StructuralPartialEq for Error

1.0.0 ยท source

impl StructuralPartialEq for AddrParseError

1.0.0 ยท source

impl StructuralPartialEq for Ipv4Addr

1.0.0 ยท source

impl StructuralPartialEq for Ipv6Addr

1.0.0 ยท source

impl StructuralPartialEq for SocketAddrV4

1.0.0 ยท source

impl StructuralPartialEq for SocketAddrV6

source

impl StructuralPartialEq for CriticalRequestComponents

1.0.0 ยท source

impl StructuralPartialEq for ParseBoolError

1.0.0 ยท source

impl StructuralPartialEq for Utf8Error

1.3.0 ยท source

impl StructuralPartialEq for Duration



impl StructuralPartialEq for HeaderName

1.8.0 ยท source

impl StructuralPartialEq for kvarn_async::prelude::Instant



impl StructuralPartialEq for Method



impl StructuralPartialEq for StatusCode



impl StructuralPartialEq for Version



impl StructuralPartialEq for ReserveError

source

impl StructuralPartialEq for AllocError

1.28.0 ยท source

impl StructuralPartialEq for Layout

1.50.0 ยท source

impl StructuralPartialEq for LayoutError

1.27.0 ยท source

impl StructuralPartialEq for CpuidResult

1.34.0 ยท source

impl StructuralPartialEq for CharTryFromError

1.9.0 ยท source

impl StructuralPartialEq for DecodeUtf16Error

1.20.0 ยท source

impl StructuralPartialEq for ParseCharError

1.59.0 ยท source

impl StructuralPartialEq for TryFromCharError

1.64.0 ยท source

impl StructuralPartialEq for CStr

1.69.0 ยท source

impl StructuralPartialEq for FromBytesUntilNulError

1.64.0 ยท source

impl StructuralPartialEq for FromBytesWithNulError

source

impl StructuralPartialEq for Assume

1.0.0 ยท source

impl StructuralPartialEq for ParseFloatError

1.0.0 ยท source

impl StructuralPartialEq for ParseIntError

1.34.0 ยท source

impl StructuralPartialEq for TryFromIntError

source

impl StructuralPartialEq for kvarn_async::prelude::compact_str::core::ptr::Alignment

1.0.0 ยท source

impl StructuralPartialEq for RangeFull

1.36.0 ยท source

impl StructuralPartialEq for RawWaker

1.36.0 ยท source

impl StructuralPartialEq for RawWakerVTable

1.66.0 ยท source

impl StructuralPartialEq for TryFromFloatSecsError

source

impl StructuralPartialEq for UnorderedKeyError

1.57.0 ยท source

impl StructuralPartialEq for TryReserveError

1.64.0 ยท source

impl StructuralPartialEq for CString

1.64.0 ยท source

impl StructuralPartialEq for FromVecWithNulError

1.64.0 ยท source

impl StructuralPartialEq for IntoStringError

1.64.0 ยท source

impl StructuralPartialEq for NulError

1.0.0 ยท source

impl StructuralPartialEq for FromUtf8Error

1.0.0 ยท source

impl StructuralPartialEq for String

1.1.0 ยท source

impl StructuralPartialEq for FileType

1.0.0 ยท source

impl StructuralPartialEq for Permissions

source

impl StructuralPartialEq for std::os::unix::net::ucred::UCred

1.7.0 ยท source

impl StructuralPartialEq for StripPrefixError

1.61.0 ยท source

impl StructuralPartialEq for ExitCode

1.0.0 ยท source

impl StructuralPartialEq for ExitStatus

source

impl StructuralPartialEq for ExitStatusError

1.0.0 ยท source

impl StructuralPartialEq for Output

1.5.0 ยท source

impl StructuralPartialEq for std::sync::condvar::WaitTimeoutResult

1.0.0 ยท source

impl StructuralPartialEq for std::sync::mpsc::RecvError

1.26.0 ยท source

impl StructuralPartialEq for AccessError

1.19.0 ยท source

impl StructuralPartialEq for ThreadId

1.8.0 ยท source

impl StructuralPartialEq for SystemTime

source

impl StructuralPartialEq for ParseLevelError

1.33.0 ยท source

impl StructuralPartialEq for PhantomPinned



impl StructuralPartialEq for Domain



impl StructuralPartialEq for Elapsed



impl StructuralPartialEq for FilterOp



impl StructuralPartialEq for Instant



impl StructuralPartialEq for Interest



impl StructuralPartialEq for Interest



impl StructuralPartialEq for MissedTickBehavior



impl StructuralPartialEq for OnceState



impl StructuralPartialEq for ParkResult



impl StructuralPartialEq for ParkToken



impl StructuralPartialEq for Protocol



impl StructuralPartialEq for Ready



impl StructuralPartialEq for RecvError



impl StructuralPartialEq for RecvError



impl StructuralPartialEq for RecvFlags



impl StructuralPartialEq for RequeueOp



impl StructuralPartialEq for RuntimeFlavor



impl StructuralPartialEq for Token



impl StructuralPartialEq for TryAcquireError



impl StructuralPartialEq for TryRecvError



impl StructuralPartialEq for TryRecvError



impl StructuralPartialEq for TryRecvError



impl StructuralPartialEq for Type



impl StructuralPartialEq for UCred



impl StructuralPartialEq for UnparkResult



impl StructuralPartialEq for UnparkToken



impl StructuralPartialEq for WaitTimeoutResult

source

impl<'a> StructuralPartialEq for Utf8Pattern<'a>

1.0.0 ยท source

impl<'a> StructuralPartialEq for Component<'a>

1.0.0 ยท source

impl<'a> StructuralPartialEq for Prefix<'a>

source

impl<'a> StructuralPartialEq for Query<'a>

source

impl<'a> StructuralPartialEq for QueryPair<'a>

source

impl<'a> StructuralPartialEq for ValueQualitySet<'a>

1.79.0 ยท source

impl<'a> StructuralPartialEq for Utf8Chunk<'a>

1.10.0 ยท source

impl<'a> StructuralPartialEq for Location<'a>

source

impl<'a> StructuralPartialEq for Metadata<'a>

source

impl<'a> StructuralPartialEq for MetadataBuilder<'a>

1.55.0 ยท source

impl<B, C> StructuralPartialEq for ControlFlow<B, C>

1.0.0 ยท source

impl<Idx> StructuralPartialEq for kvarn_async::prelude::compact_str::core::range::legacy::Range<Idx>

1.0.0 ยท source

impl<Idx> StructuralPartialEq for kvarn_async::prelude::compact_str::core::range::legacy::RangeFrom<Idx>

1.26.0 ยท source

impl<Idx> StructuralPartialEq for kvarn_async::prelude::compact_str::core::range::legacy::RangeInclusive<Idx>

source

impl<Idx> StructuralPartialEq for kvarn_async::prelude::compact_str::core::range::Range<Idx>

source

impl<Idx> StructuralPartialEq for kvarn_async::prelude::compact_str::core::range::RangeFrom<Idx>

source

impl<Idx> StructuralPartialEq for kvarn_async::prelude::compact_str::core::range::RangeInclusive<Idx>

1.0.0 ยท source

impl<Idx> StructuralPartialEq for RangeTo<Idx>

1.26.0 ยท source

impl<Idx> StructuralPartialEq for RangeToInclusive<Idx>

1.0.0 ยท source

impl<T> StructuralPartialEq for Option<T>

1.17.0 ยท source

impl<T> StructuralPartialEq for Bound<T>

1.36.0 ยท source

impl<T> StructuralPartialEq for Poll<T>

source

impl<T> StructuralPartialEq for std::sync::mpmc::error::SendTimeoutError<T>

1.0.0 ยท source

impl<T> StructuralPartialEq for std::sync::mpsc::TrySendError<T>

source

impl<T> StructuralPartialEq for &T
where T: ?Sized,

source

impl<T> StructuralPartialEq for [T]

source

impl<T> StructuralPartialEq for (Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™)

This trait is implemented for tuples up to twelve items long.

1.0.0 ยท source

impl<T> StructuralPartialEq for Cursor<T>

1.19.0 ยท source

impl<T> StructuralPartialEq for Reverse<T>

1.20.0 ยท source

impl<T> StructuralPartialEq for ManuallyDrop<T>
where T: ?Sized,

source

impl<T> StructuralPartialEq for NonZero<T>

1.74.0 ยท source

impl<T> StructuralPartialEq for Saturating<T>

1.0.0 ยท source

impl<T> StructuralPartialEq for Wrapping<T>

1.0.0 ยท source

impl<T> StructuralPartialEq for std::sync::mpsc::SendError<T>

source

impl<T> StructuralPartialEq for PhantomData<T>
where T: ?Sized,



impl<T> StructuralPartialEq for SendError<T>



impl<T> StructuralPartialEq for SendError<T>



impl<T> StructuralPartialEq for SendTimeoutError<T>



impl<T> StructuralPartialEq for SetError<T>



impl<T> StructuralPartialEq for TrySendError<T>

1.0.0 ยท source

impl<T, E> StructuralPartialEq for Result<T, E>

source

impl<T, const N: usize> StructuralPartialEq for [T; N]

source

impl<Y, R> StructuralPartialEq for CoroutineState<Y, R>